@@ -2,6 +2,7 @@
 Upgrade command evaluates a current set of templates and
 checks whether or not the deployed version could be updated.
 """
+# pylint: disable=line-too-long
 import logging
 import os
 
@@ -15,6 +16,8 @@ CONFIG_DEFAULT = os.path.abspath(os.path.join(os.getcwd(), "reflex.yaml"))
 SHORT_UPGRADE_HELP = (
     "Evaluates existing reflex deployment for possible upgrades."
 )
+BOLD = "\033[1m"
+ENDC = "\033[0m"
 
 
 @click.command("upgrade", short_help=SHORT_UPGRADE_HELP)
@@ -32,11 +35,25 @@ SHORT_UPGRADE_HELP = (
     is_flag=True,
     help="Chooses to upgrade all possible rules.",
 )
-def cli(select_all, config):
-    """CLI entrypoint for upgrade command."""
+@click.option(
+    "-r", "--rule", help="Specify a rule that you would like to upgrade."
+)
+def cli(rule, select_all, config):
+    """
+    Compares a local configuration file with external version information to allow users to upgrade rule versions automatically within their configuration.
+
+    By default, configuration file name is set to be reflex.yaml.
+    """
     LOGGER.info(
-        "Determining if upgrade is needed for reflex deploy at in: %s", config
+        "%s⏫ Determining if upgrade is needed for reflex deploy at in: %s%s",
+        BOLD,
+        config,
+        ENDC,
     )
     updater = ConfigVersionUpdater(config, select_all)
-    updater.compare_current_rule_versions()
-    updater.overwrite_reflex_config()
+    if rule:
+        update_requested = updater.compare_current_rule_version(rule)
+    else:
+        update_requested = updater.compare_current_rule_versions()
+    if update_requested:
+        updater.overwrite_reflex_config()
